@@ -2,18 +2,12 @@
 #define _LC_GLOBAL_H_
 
 #include "lc_config.h"
-#include "defines.h"
 
 // Version number.
 #define LC_VERSION_MAJOR 0
 #define LC_VERSION_MINOR 80
-#define LC_VERSION_PATCH 0
-#define LC_VERSION_TEXT "0.80.0"
-
-// Check for supported platforms.
-#ifndef LC_QT
-#error No OS defined.
-#endif
+#define LC_VERSION_PATCH 2
+#define LC_VERSION_TEXT "0.80.2"
 
 // Forward declarations.
 class lcVector2;
