@@ -9,7 +9,12 @@
 #define LC_PI   3.141592f
 #define LC_2PI  6.283185f
 
-#define LC_RGB(r,g,b) ((lcuint32)(((lcuint8) (r) | ((lcuint16) (g) << 8))|(((lcuint32) (lcuint8) (b)) << 16))) 
+#define LC_RGB(r,g,b) LC_RGBA(r,g,b,255)
+#define LC_RGBA(r,g,b,a) ((lcuint32)(((lcuint8) (r) | ((lcuint16) (g) << 8)) | (((lcuint32) (lcuint8) (b)) << 16) | (((lcuint32) (lcuint8) (a)) << 24))) 
+#define LC_RGBA_RED(rgba)   ((lcuint8)(((rgba) >>  0) & 0xff))
+#define LC_RGBA_GREEN(rgba) ((lcuint8)(((rgba) >>  8) & 0xff))
+#define LC_RGBA_BLUE(rgba)  ((lcuint8)(((rgba) >> 16) & 0xff))
+#define LC_RGBA_ALPHA(rgba) ((lcuint8)(((rgba) >> 24) & 0xff))
 #define LC_FLOATRGB(f) LC_RGB(f[0]*255, f[1]*255, f[2]*255)
 
 template <typename T, typename U>
@@ -342,6 +347,14 @@ inline lcVector3 lcNormalize(const lcVector3& a)
 	return Ret;
 }
 
+inline void lcAlign(lcVector3& t, const lcVector3& a, const lcVector3& b)
+{
+	lcVector3 Vector(b - a);
+	Vector.Normalize();
+	Vector *=  (t - a).Length();
+	t = a + Vector;
+}
+
 inline float lcDot(const lcVector3& a, const lcVector3& b)
 {
 	return a.x * b.x + a.y * b.y + a.z * b.z;
@@ -442,6 +455,13 @@ inline lcVector4& operator/=(lcVector4& a, float b)
 	return a;
 }
 
+inline lcVector4 lcVector4FromColor(lcuint32 Color)
+{
+	lcVector4 v(LC_RGBA_RED(Color), LC_RGBA_GREEN(Color), LC_RGBA_BLUE(Color), LC_RGBA_ALPHA(Color));
+	v /= 255.0f;
+	return v;
+}
+
 inline lcVector3 lcMul31(const lcVector3& a, const lcMatrix44& b)
 {
 	lcVector4 v = b.r[0] * a[0] + b.r[1] * a[1] + b.r[2] * a[2] + b.r[3];
