@@ -8,7 +8,10 @@ bool GL_ExtensionSupported(const GLubyte* Extensions, const char* Name);
 
 extern bool GL_SupportsVertexBufferObject;
 extern bool GL_UseVertexBufferObject;
-extern bool GL_SupportsFramebufferObject;
+extern bool GL_SupportsFramebufferObjectARB;
+extern bool GL_SupportsFramebufferObjectEXT;
+extern bool GL_SupportsAnisotropic;
+extern GLfloat GL_MaxAnisotropy;
 
 inline void GL_DisableVertexBufferObject()
 {
@@ -25,9 +28,14 @@ inline bool GL_HasVertexBufferObject()
 	return GL_UseVertexBufferObject;
 }
 
-inline bool GL_HasFramebufferObject()
+inline bool GL_HasFramebufferObjectARB()
 {
-	return GL_SupportsFramebufferObject;
+	return GL_SupportsFramebufferObjectARB;
+}
+
+inline bool GL_HasFramebufferObjectEXT()
+{
+	return GL_SupportsFramebufferObjectEXT;
 }
 
 bool GL_BeginRenderToTexture(int Width, int Height);
@@ -88,6 +96,11 @@ typedef ptrdiff_t GLintptrARB;
 typedef ptrdiff_t GLsizeiptrARB;
 #endif
 
+#ifndef GL_EXT_texture_filter_anisotropic
+#define GL_TEXTURE_MAX_ANISOTROPY_EXT                0x84FE
+#define GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT            0x84FF
+#endif
+
 #ifndef GL_ARB_vertex_buffer_object
 #define GL_BUFFER_SIZE_ARB                           0x8764
 #define GL_BUFFER_USAGE_ARB                          0x8765
@@ -248,6 +261,80 @@ typedef void (APIENTRY *GLBLITFRAMEBUFFERARBPROC) (GLint srcX0, GLint srcY0, GLi
 typedef void (APIENTRY *GLRENDERBUFFERSTORAGEMULTISAMPLEARBPROC) (GLenum target, GLsizei samples, GLenum internalformat, GLsizei width, GLsizei height);
 typedef void (APIENTRY *GLFRAMEBUFFERTEXTURELAYERARBPROC) (GLenum target, GLenum attachment, GLuint texture, GLint level, GLint layer);
 
+#ifndef GL_EXT_framebuffer_object
+#define GL_EXT_framebuffer_object 1
+#define GL_INVALID_FRAMEBUFFER_OPERATION_EXT 0x0506
+#define GL_MAX_RENDERBUFFER_SIZE_EXT      0x84E8
+#define GL_FRAMEBUFFER_BINDING_EXT        0x8CA6
+#define GL_RENDERBUFFER_BINDING_EXT       0x8CA7
+#define GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE_EXT 0x8CD0
+#define GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME_EXT 0x8CD1
+#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL_EXT 0x8CD2
+#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE_EXT 0x8CD3
+#define GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_3D_ZOFFSET_EXT 0x8CD4
+#define GL_FRAMEBUFFER_COMPLETE_EXT       0x8CD5
+#define GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT_EXT 0x8CD6
+#define GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT_EXT 0x8CD7
+#define GL_FRAMEBUFFER_INCOMPLETE_DIMENSIONS_EXT 0x8CD9
+#define GL_FRAMEBUFFER_INCOMPLETE_FORMATS_EXT 0x8CDA
+#define GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER_EXT 0x8CDB
+#define GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER_EXT 0x8CDC
+#define GL_FRAMEBUFFER_UNSUPPORTED_EXT    0x8CDD
+#define GL_MAX_COLOR_ATTACHMENTS_EXT      0x8CDF
+#define GL_COLOR_ATTACHMENT0_EXT          0x8CE0
+#define GL_COLOR_ATTACHMENT1_EXT          0x8CE1
+#define GL_COLOR_ATTACHMENT2_EXT          0x8CE2
+#define GL_COLOR_ATTACHMENT3_EXT          0x8CE3
+#define GL_COLOR_ATTACHMENT4_EXT          0x8CE4
+#define GL_COLOR_ATTACHMENT5_EXT          0x8CE5
+#define GL_COLOR_ATTACHMENT6_EXT          0x8CE6
+#define GL_COLOR_ATTACHMENT7_EXT          0x8CE7
+#define GL_COLOR_ATTACHMENT8_EXT          0x8CE8
+#define GL_COLOR_ATTACHMENT9_EXT          0x8CE9
+#define GL_COLOR_ATTACHMENT10_EXT         0x8CEA
+#define GL_COLOR_ATTACHMENT11_EXT         0x8CEB
+#define GL_COLOR_ATTACHMENT12_EXT         0x8CEC
+#define GL_COLOR_ATTACHMENT13_EXT         0x8CED
+#define GL_COLOR_ATTACHMENT14_EXT         0x8CEE
+#define GL_COLOR_ATTACHMENT15_EXT         0x8CEF
+#define GL_DEPTH_ATTACHMENT_EXT           0x8D00
+#define GL_STENCIL_ATTACHMENT_EXT         0x8D20
+#define GL_FRAMEBUFFER_EXT                0x8D40
+#define GL_RENDERBUFFER_EXT               0x8D41
+#define GL_RENDERBUFFER_WIDTH_EXT         0x8D42
+#define GL_RENDERBUFFER_HEIGHT_EXT        0x8D43
+#define GL_RENDERBUFFER_INTERNAL_FORMAT_EXT 0x8D44
+#define GL_STENCIL_INDEX1_EXT             0x8D46
+#define GL_STENCIL_INDEX4_EXT             0x8D47
+#define GL_STENCIL_INDEX8_EXT             0x8D48
+#define GL_STENCIL_INDEX16_EXT            0x8D49
+#define GL_RENDERBUFFER_RED_SIZE_EXT      0x8D50
+#define GL_RENDERBUFFER_GREEN_SIZE_EXT    0x8D51
+#define GL_RENDERBUFFER_BLUE_SIZE_EXT     0x8D52
+#define GL_RENDERBUFFER_ALPHA_SIZE_EXT    0x8D53
+#define GL_RENDERBUFFER_DEPTH_SIZE_EXT    0x8D54
+#define GL_RENDERBUFFER_STENCIL_SIZE_EXT  0x8D55
+#endif
+
+// GL_EXT_framebuffer_object
+typedef GLboolean (APIENTRY *GLISRENDERBUFFEREXTPROC) (GLuint renderbuffer);
+typedef void (APIENTRY *GLBINDRENDERBUFFEREXTPROC) (GLenum target, GLuint renderbuffer);
+typedef void (APIENTRY *GLDELETERENDERBUFFERSEXTPROC) (GLsizei n, const GLuint *renderbuffers);
+typedef void (APIENTRY *GLGENRENDERBUFFERSEXTPROC) (GLsizei n, GLuint *renderbuffers);
+typedef void (APIENTRY *GLRENDERBUFFERSTORAGEEXTPROC) (GLenum target, GLenum internalformat, GLsizei width, GLsizei height);
+typedef void (APIENTRY *GLGETRENDERBUFFERPARAMETERIVEXTPROC) (GLenum target, GLenum pname, GLint *params);
+typedef GLboolean (APIENTRY *GLISFRAMEBUFFEREXTPROC) (GLuint framebuffer);
+typedef void (APIENTRY *GLBINDFRAMEBUFFEREXTPROC) (GLenum target, GLuint framebuffer);
+typedef void (APIENTRY *GLDELETEFRAMEBUFFERSEXTPROC) (GLsizei n, const GLuint *framebuffers);
+typedef void (APIENTRY *GLGENFRAMEBUFFERSEXTPROC) (GLsizei n, GLuint *framebuffers);
+typedef GLenum (APIENTRY *GLCHECKFRAMEBUFFERSTATUSEXTPROC) (GLenum target);
+typedef void (APIENTRY *GLFRAMEBUFFERTEXTURE1DEXTPROC) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
+typedef void (APIENTRY *GLFRAMEBUFFERTEXTURE2DEXTPROC) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level);
+typedef void (APIENTRY *GLFRAMEBUFFERTEXTURE3DEXTPROC) (GLenum target, GLenum attachment, GLenum textarget, GLuint texture, GLint level, GLint zoffset);
+typedef void (APIENTRY *GLFRAMEBUFFERRENDERBUFFEREXTPROC) (GLenum target, GLenum attachment, GLenum renderbuffertarget, GLuint renderbuffer);
+typedef void (APIENTRY *GLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC) (GLenum target, GLenum attachment, GLenum pname, GLint *params);
+typedef void (APIENTRY *GLGENERATEMIPMAPEXTPROC) (GLenum target);
+
 extern GLBINDBUFFERARBPROC lcBindBufferARB;
 extern GLDELETEBUFFERSARBPROC lcDeleteBuffersARB;
 extern GLGENBUFFERSARBPROC lcGenBuffersARB;
@@ -281,6 +368,24 @@ extern GLBLITFRAMEBUFFERARBPROC lcBlitFramebufferARB;
 extern GLRENDERBUFFERSTORAGEMULTISAMPLEARBPROC lcRenderbufferStorageMultisampleARB;
 extern GLFRAMEBUFFERTEXTURELAYERARBPROC lcFramebufferTextureLayerARB;
 
+extern GLISRENDERBUFFEREXTPROC lcIsRenderbufferEXT;
+extern GLBINDRENDERBUFFEREXTPROC lcBindRenderbufferEXT;
+extern GLDELETERENDERBUFFERSEXTPROC lcDeleteRenderbuffersEXT;
+extern GLGENRENDERBUFFERSEXTPROC lcGenRenderbuffersEXT;
+extern GLRENDERBUFFERSTORAGEEXTPROC lcRenderbufferStorageEXT;
+extern GLGETRENDERBUFFERPARAMETERIVEXTPROC lcGetRenderbufferParameterivEXT;
+extern GLISFRAMEBUFFEREXTPROC lcIsFramebufferEXT;
+extern GLBINDFRAMEBUFFEREXTPROC lcBindFramebufferEXT;
+extern GLDELETEFRAMEBUFFERSEXTPROC lcDeleteFramebuffersEXT;
+extern GLGENFRAMEBUFFERSEXTPROC lcGenFramebuffersEXT;
+extern GLCHECKFRAMEBUFFERSTATUSEXTPROC lcCheckFramebufferStatusEXT;
+extern GLFRAMEBUFFERTEXTURE1DEXTPROC lcFramebufferTexture1DEXT;
+extern GLFRAMEBUFFERTEXTURE2DEXTPROC lcFramebufferTexture2DEXT;
+extern GLFRAMEBUFFERTEXTURE3DEXTPROC lcFramebufferTexture3DEXT;
+extern GLFRAMEBUFFERRENDERBUFFEREXTPROC lcFramebufferRenderbufferEXT;
+extern GLGETFRAMEBUFFERATTACHMENTPARAMETERIVEXTPROC lcGetFramebufferAttachmentParameterivEXT;
+extern GLGENERATEMIPMAPEXTPROC lcGenerateMipmapEXT;
+
 #define glBindBuffer lcBindBufferARB
 #define glDeleteBuffers lcDeleteBuffersARB
 #define glGenBuffers lcGenBuffersARB
@@ -314,4 +419,22 @@ extern GLFRAMEBUFFERTEXTURELAYERARBPROC lcFramebufferTextureLayerARB;
 #define glRenderbufferStorageMultisample lcRenderbufferStorageMultisampleARB
 #define glFramebufferTextureLayer lcFramebufferTextureLayerARB
 
+#define glIsRenderbufferEXT lcIsRenderbufferEXT
+#define glBindRenderbufferEXT lcBindRenderbufferEXT
+#define glDeleteRenderbuffersEXT lcDeleteRenderbuffersEXT
+#define glGenRenderbuffersEXT lcGenRenderbuffersEXT
+#define glRenderbufferStorageEXT lcRenderbufferStorageEXT
+#define glGetRenderbufferParameterivEXT lcGetRenderbufferParameterivEXT
+#define glIsFramebufferEXT lcIsFramebufferEXT
+#define glBindFramebufferEXT lcBindFramebufferEXT
+#define glDeleteFramebuffersEXT lcDeleteFramebuffersEXT
+#define glGenFramebuffersEXT lcGenFramebuffersEXT
+#define glCheckFramebufferStatusEXT lcCheckFramebufferStatusEXT
+#define glFramebufferTexture1DEXT lcFramebufferTexture1DEXT
+#define glFramebufferTexture2DEXT lcFramebufferTexture2DEXT
+#define glFramebufferTexture3DEXT lcFramebufferTexture3DEXT
+#define glFramebufferRenderbufferEXT lcFramebufferRenderbufferEXT
+#define glGetFramebufferAttachmentParameterivEXT lcGetFramebufferAttachmentParameterivEXT
+#define glGenerateMipmapEXT lcGenerateMipmapEXT
+
 #endif // _OPENGL_H_
