@@ -13,12 +13,13 @@
 #include "piece.h"
 #include "camera.h"
 #include "view.h"
+#include "group.h"
 #include "lc_qpartstree.h"
 #include "lc_qcolorlist.h"
 #include "lc_qpropertiestree.h"
 #include "lc_shortcuts.h"
 #include "system.h"
-#include "mainwnd.h"
+#include "lc_mainwindow.h"
 #include "lc_profile.h"
 
 lcQMainWindow::lcQMainWindow(QWidget *parent)
@@ -26,6 +27,7 @@ lcQMainWindow::lcQMainWindow(QWidget *parent)
 {
 	memset(actions, 0, sizeof(actions));
 
+	setWindowIcon(QIcon(":/resources/icon64.png"));
 	setWindowFilePath(QString());
 
 	createActions();
@@ -76,10 +78,9 @@ lcQMainWindow::lcQMainWindow(QWidget *parent)
 
 	QSettings settings;
 	settings.beginGroup("MainWindow");
-	QPoint pos = settings.value("Position", QPoint(200, 200)).toPoint();
-	QSize size = settings.value("Size", QSize(800, 600)).toSize();
-	resize(size);
-	move(pos);
+	resize(QSize(800, 600));
+	move(QPoint(200, 200));
+	restoreGeometry(settings.value("Geometry").toByteArray());
 	restoreState(settings.value("State").toByteArray());
 	settings.endGroup();
 }
@@ -194,6 +195,13 @@ void lcQMainWindow::createActions()
 		actionCameraGroup->addAction(actions[actionIdx]);
 	}
 
+	QActionGroup *actionPerspectiveGroup = new QActionGroup(this);
+	for (int actionIdx = LC_VIEW_PROJECTION_FIRST; actionIdx <= LC_VIEW_PROJECTION_LAST; actionIdx++)
+	{
+		actions[actionIdx]->setCheckable(true);
+		actionPerspectiveGroup->addAction(actions[actionIdx]);
+	}
+
 	updateShortcuts();
 }
 
@@ -297,6 +305,7 @@ void lcQMainWindow::createMenus()
 	menuView->addAction(actions[LC_VIEW_PREFERENCES]);
 	menuView->addSeparator();
 	menuView->addAction(actions[LC_VIEW_ZOOM_EXTENTS]);
+	menuView->addAction(actions[LC_VIEW_LOOK_AT]);
 	QMenu* menuViewpoints = menuView->addMenu(tr("&Viewpoints"));
 	menuViewpoints->addAction(actions[LC_VIEW_VIEWPOINT_FRONT]);
 	menuViewpoints->addAction(actions[LC_VIEW_VIEWPOINT_BACK]);
@@ -306,6 +315,9 @@ void lcQMainWindow::createMenus()
 	menuViewpoints->addAction(actions[LC_VIEW_VIEWPOINT_BOTTOM]);
 	menuViewpoints->addAction(actions[LC_VIEW_VIEWPOINT_HOME]);
 	menuView->addMenu(menuCamera);
+	QMenu* menuPerspective = menuView->addMenu(tr("Projection"));
+	menuPerspective->addAction(actions[LC_VIEW_PROJECTION_PERSPECTIVE]);
+	menuPerspective->addAction(actions[LC_VIEW_PROJECTION_ORTHO]);
 	QMenu* menuStep = menuView->addMenu(tr("Ste&p"));
 	menuStep->addAction(actions[LC_VIEW_TIME_FIRST]);
 	menuStep->addAction(actions[LC_VIEW_TIME_PREVIOUS]);
@@ -331,12 +343,11 @@ void lcQMainWindow::createMenus()
 	menuToolBars->addAction(timeToolBar->toggleViewAction());
 	menuView->addAction(actions[LC_VIEW_FULLSCREEN]);
 
-	menuPiece = menuBar()->addMenu(tr("&Part"));
+	menuPiece = menuBar()->addMenu(tr("&Piece"));
 	menuPiece->addAction(actions[LC_PIECE_INSERT]);
 	menuPiece->addAction(actions[LC_PIECE_DELETE]);
 	menuPiece->addAction(actions[LC_PIECE_ARRAY]);
 	menuPiece->addAction(actions[LC_PIECE_MINIFIG_WIZARD]);
-	//	LC_PIECE_COPY_KEYS
 	menuPiece->addSeparator();
 	menuPiece->addAction(actions[LC_PIECE_GROUP]);
 	menuPiece->addAction(actions[LC_PIECE_UNGROUP]);
@@ -459,8 +470,11 @@ void lcQMainWindow::createToolBars()
 	piecePreview->preferredSize = QSize(200, 100);
 	previewLayout->addWidget(piecePreview, 0, 0, 1, 1);
 
+	QSizePolicy treePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+	treePolicy.setVerticalStretch(1);
+
 	partsTree = new lcQPartsTree(partsSplitter);
-	partsTree->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::Preferred);
+	partsTree->setSizePolicy(treePolicy);
 	connect(partsTree, SIGNAL(currentItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)), this, SLOT(partsTreeItemChanged(QTreeWidgetItem*, QTreeWidgetItem*)));
 
 	partSearch = new QLineEdit(partsSplitter);
@@ -526,8 +540,7 @@ void lcQMainWindow::closeEvent(QCloseEvent *event)
 
 		QSettings settings;
 		settings.beginGroup("MainWindow");
-		settings.setValue("Position", pos());
-		settings.setValue("Size", size());
+		settings.setValue("Geometry", saveGeometry());
 		settings.setValue("State", saveState());
 		settings.endGroup();
 	}
@@ -565,6 +578,9 @@ void lcQMainWindow::actionTriggered()
 
 void lcQMainWindow::partsTreeItemChanged(QTreeWidgetItem *current, QTreeWidgetItem *previous)
 {
+	if (!current)
+		return;
+
 	PieceInfo *info = (PieceInfo*)current->data(0, lcQPartsTree::PartInfoRole).value<void*>();
 
 	if (info)
@@ -587,7 +603,8 @@ void lcQMainWindow::partSearchReturn()
 
 void lcQMainWindow::partSearchChanged(const QString& text)
 {
-	const char *searchString = text.toLocal8Bit().data();
+	const QByteArray textConv = text.toLocal8Bit();
+	const char* searchString = textConv.data();
 	int length = strlen(searchString);
 
 	if (!length)
@@ -1049,16 +1066,15 @@ void lcQMainWindow::updateSelectedObjects(int flags, int selectedCount, Object*
 {
 	actions[LC_EDIT_CUT]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
 	actions[LC_EDIT_COPY]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
-	actions[LC_EDIT_FIND]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
-	actions[LC_EDIT_FIND_NEXT]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
-	actions[LC_EDIT_FIND_PREVIOUS]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
+	actions[LC_EDIT_FIND]->setEnabled((flags & LC_SEL_NO_PIECES) == 0);
+	actions[LC_EDIT_FIND_NEXT]->setEnabled((flags & LC_SEL_NO_PIECES) == 0);
+	actions[LC_EDIT_FIND_PREVIOUS]->setEnabled((flags & LC_SEL_NO_PIECES) == 0);
 	actions[LC_EDIT_SELECT_INVERT]->setEnabled((flags & LC_SEL_NO_PIECES) == 0);
 	actions[LC_EDIT_SELECT_BY_NAME]->setEnabled((flags & LC_SEL_NO_PIECES) == 0);
 	actions[LC_EDIT_SELECT_NONE]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
 	actions[LC_EDIT_SELECT_ALL]->setEnabled(flags & LC_SEL_UNSELECTED);
 
 	actions[LC_PIECE_DELETE]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
-	actions[LC_PIECE_COPY_KEYS]->setEnabled(flags & (LC_SEL_PIECE | LC_SEL_CAMERA | LC_SEL_LIGHT));
 	actions[LC_PIECE_ARRAY]->setEnabled(flags & LC_SEL_PIECE);
 	actions[LC_PIECE_HIDE_SELECTED]->setEnabled(flags & LC_SEL_PIECE);
 	actions[LC_PIECE_UNHIDE_ALL]->setEnabled(flags & LC_SEL_HIDDEN);
@@ -1086,6 +1102,15 @@ void lcQMainWindow::updateSelectedObjects(int flags, int selectedCount, Object*
 			message = "1 Object selected";
 		else
 			message = QString("%1 Objects selected").arg(QString::number(selectedCount));
+
+		if ((focus != NULL) && focus->IsPiece())
+		{
+			message.append(QString(" - %1 (ID: %2)").arg(focus->GetName(), ((Piece*)focus)->mPieceInfo->m_strName));
+
+			const Group* pGroup = ((Piece*)focus)->GetGroup();
+			if ((pGroup != NULL) && pGroup->m_strName[0])
+				message.append(QString(" in group '%1'").arg(pGroup->m_strName));
+		}
 	}
 
 	statusBarLabel->setText(message);
@@ -1128,8 +1153,6 @@ void lcQMainWindow::updateAnimation(bool animation, bool addKeys)
 	gtk_widget_set_sensitive (anim_toolbar.stop, FALSE);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(anim_toolbar.anim), bAnimation);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(anim_toolbar.keys), bAddKeys);
-	gpointer item = gtk_object_get_data (GTK_OBJECT (((GtkWidget*)(*main_window))), "menu_piece_copykeys");
-	gtk_label_set_text (GTK_LABEL (GTK_BIN (item)->child), bAnimation ? "Copy Keys from Instructions" : "Copy Keys from Animation");
 	*/
 }
 
@@ -1203,7 +1226,7 @@ void lcQMainWindow::updateTransformType(int newType)
 	actions[LC_EDIT_TRANSFORM]->setIcon(QIcon(iconNames[newType]));
 }
 
-void lcQMainWindow::updateCameraMenu(const PtrArray<Camera>& cameras, Camera* currentCamera)
+void lcQMainWindow::updateCameraMenu(const lcArray<Camera*>& cameras, Camera* currentCamera)
 {
 	int actionIdx, currentIndex = -1;
 
@@ -1237,6 +1260,16 @@ void lcQMainWindow::updateCurrentCamera(int cameraIndex)
 	actions[actionIndex]->setChecked(true);
 }
 
+void lcQMainWindow::updatePerspective(View* view)
+{
+	lcProjection::Type type = view->GetProjectionType();
+
+	if (lcProjection::Projection == type)
+		actions[LC_VIEW_PROJECTION_PERSPECTIVE]->setChecked(true);
+	else
+		actions[LC_VIEW_PROJECTION_ORTHO]->setChecked(true);
+}
+
 void lcQMainWindow::updateCategories()
 {
 	partsTree->updateCategories();
